.. Everviz documentation master file, created by
   sphinx-quickstart on Fri Apr  3 10:45:36 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Everviz documentation
=====================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   installing_everviz
   running_everviz

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
